---
author: Max Grover
date: 2022-04-01
tags: annoucement
---

# New Docs

Hello All!

Welcome to our new documentation page! This is a **new section** within the docs meant for:
* General updates
* Release overviews
* More narrative-oriented examples

If you have any feedback on this new site, feel free to let us know using that Github button in the top right corner!
